
History
=======

v0.1.2
------
* Fix bug where historical data SL covariance matrix was top-coded at 0 instead of bottom-coded
* Fix bug where historical data T0 was incorrectly calculated

v0.1.1
------
* Initial commit containing ``load_data_SESL``, ``calc_temp``, and ``calc_T0`` functions
